import { Telemetry } from '../telemetry';
import { BaseEntity, BaseRecord, QueryOptions } from './types';
export * from './types';
export interface DatabaseConfig {
    url: string;
}
export declare abstract class MastraEngine {
    #private;
    /**
     * Initializes the database connection
     * @param config Configuration object for database connection
     */
    constructor(config: DatabaseConfig);
    /**
     * Set the telemetry on the engine
     * @param telemetry
     */
    __setTelemetry(telemetry: Telemetry): void;
    /**
     * Get the telemetry on the engine
     * @returns telemetry
     */
    __getTelemetry(): Telemetry | undefined;
    abstract createEntity(params: {
        name: string;
        connectionId: string;
    }): Promise<BaseEntity>;
    abstract getEntityById(params: {
        id: string;
    }): Promise<BaseEntity>;
    abstract getEntity({ connectionId, name }: {
        name?: string;
        connectionId?: string;
    }): Promise<BaseEntity | undefined>;
    abstract deleteEntityById({ id }: {
        id: string;
    }): Promise<BaseEntity>;
    abstract upsertRecords(params: {
        entityId: string;
        records: Pick<BaseRecord, 'externalId' | 'data' | 'entityType'>[];
    }): Promise<void>;
    abstract getRecordsByEntityId(params: {
        entityId: string;
    }): Promise<BaseRecord[]>;
    abstract getRecordsByEntityName({ name, connectionId, }: {
        name: string;
        connectionId: string;
    }): Promise<BaseRecord[]>;
    abstract getRecords({ entityName, connectionId, options, }: {
        entityName: string;
        options: QueryOptions;
        connectionId: string;
    }): Promise<BaseRecord[]>;
    abstract syncRecords({ connectionId, name, records, lastSyncId, }: {
        name: string;
        connectionId: string;
        records: Pick<BaseRecord, 'externalId' | 'data'>[];
        lastSyncId?: string;
    }): Promise<void>;
    protected getTelemetry(): Telemetry | undefined;
}
