import { z } from 'zod';
import { Agent } from '../agent';
import { MastraEngine } from '../engine';
import { Integration } from '../integration';
import { LLM } from '../llm';
import { ModelConfig } from '../llm/types';
import { BaseLogger } from '../logger';
import { MastraMemory } from '../memory';
import { Run } from '../run/types';
import { syncApi } from '../sync/types';
import { Telemetry, OtelConfig } from '../telemetry';
import { AllTools, ToolApi } from '../tools/types';
import { MastraVector } from '../vector';
import { Workflow } from '../workflows';
import { StripUndefined } from './types';
export declare class Mastra<TIntegrations extends Integration[], MastraTools extends Record<string, any>, TSyncs extends Record<string, syncApi<any, any>>, TLogger extends BaseLogger = BaseLogger> {
    #private;
    engine?: MastraEngine;
    private vectors?;
    private tools;
    private agents;
    private integrations;
    private logger;
    private syncs;
    private telemetry?;
    memory?: MastraMemory;
    constructor(config?: {
        tools?: MastraTools;
        memory?: MastraMemory;
        syncs?: TSyncs;
        agents?: Agent<MastraTools, TIntegrations>[];
        integrations?: TIntegrations;
        engine?: MastraEngine;
        vectors?: Record<string, MastraVector>;
        logger?: TLogger;
        workflows?: Workflow[];
        telemetry?: OtelConfig;
    });
    LLM(modelConfig: ModelConfig): LLM<MastraTools, TIntegrations, keyof (MastraTools extends Record<string, ToolApi<any, any>> ? MastraTools : {}) | keyof (TIntegrations extends Integration[] ? (import("..").IntegrationTools<StripUndefined<TIntegrations>[number]> extends infer T ? T extends import("..").IntegrationTools<StripUndefined<TIntegrations>[number]> ? T extends any ? (k: T) => void : never : never : never) extends (k: infer I) => void ? I : never : {})>;
    sync<K extends keyof TSyncs>(key: K, params: TSyncs[K]['schema']['_input'], runId?: Run['runId']): Promise<StripUndefined<TSyncs[K]['outputShema']>['_input']>;
    getAgent(name: string): Agent<MastraTools, TIntegrations, keyof (MastraTools extends Record<string, ToolApi<any, any>> ? MastraTools : {}) | keyof (TIntegrations extends Integration[] ? (import("..").IntegrationTools<StripUndefined<TIntegrations>[number]> extends infer T ? T extends import("..").IntegrationTools<StripUndefined<TIntegrations>[number]> ? T extends any ? (k: T) => void : never : never : never) extends (k: infer I) => void ? I : never : {})>;
    getWorkflow(name: string): Workflow<any, any>;
    getIntegration<I extends TIntegrations[number]['name']>(name: I): Extract<TIntegrations[number], {
        name: I;
    }>;
    getTool<T extends keyof MastraTools>(name: T): MastraTools[T] & {
        execute: <IN extends MastraTools[T]["schema"], OUT extends StripUndefined<MastraTools[T]["outputSchema"]>>(params: z.infer<IN>, runId?: Run["runId"]) => Promise<z.infer<OUT>>;
    };
    availableIntegrations(): {
        name: string;
        integration: Integration;
    }[];
    getTools(): AllTools<MastraTools, TIntegrations>;
    setLogger({ logger }: {
        logger: TLogger;
    }): void;
    getLogger(): TLogger;
    getTelemetry(): Telemetry | undefined;
    getLogsByRunId(runId: string): Promise<import("..").BaseLogMessage[]>;
}
